@@ -1,3 +1,3 @@
-from .DB import DB
+from .DB import DB, Collection
 
 from ._version import __version__
\ No newline at end of file
